@@ -1,7 +1,11 @@
 use std::convert::TryFrom;
+#[cfg(test)]
+use std::convert::TryInto;
 
+use arrayvec::ArrayVec;
 use smartstring::alias::String;
 
+use crate::genre::Genre;
 use crate::Error;
 use crate::Title;
 use crate::TitleType;
@@ -14,19 +18,19 @@ pub struct Movie {
 	pub is_adult: bool,
 	pub year: u16,
 	pub runtime_minutes: Option<u16>,
-	pub genres: Vec<String>
+	pub genres: ArrayVec<Genre, 3>
 }
 
 impl Movie {
 	#[cfg(test)]
-	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, year: u16, runtime_minutes: Option<u16>, genres: &[&str]) -> Self {
+	pub(crate) fn new(imdb_id: u32, title: &str, is_adult: bool, year: u16, runtime_minutes: Option<u16>, genres: &[Genre]) -> Self {
 		Self{
 			imdb_id,
 			title: String::from(title),
 			is_adult,
 			year,
 			runtime_minutes,
-			genres: genres.iter().map(|s| String::from(*s)).collect()
+			genres: genres.try_into().unwrap()
 		}
 	}
 
